module.exports = function(grunt) {
    grunt.initConfig({
        pkg: grunt.file.readJSON('package.json'),

        clean: {
            build: ['tmp', 'public']
        },

        compress: {
            release: {
                options: {
                    archive: 'release/<%= pkg.version %>/<%= pkg.name %>-<%= pkg.version %>.tar.gz'
                },

                expand : true,
                flatten: true,
                src : 'public/*',
                dest : '<%= pkg.name %>/<%= pkg.version %>/'
            }
        },

        copy: {
            release: {
                src : '{LICENSE.md,README.md,HISTORY.md}',
                dest: 'public/'
            },
            icons: {
                expand: true,
                cwd: 'src/',
                src: 'icons/**',
                dest: 'public/icons',
                flatten: true,
                filter: 'isFile',
            },
        },

        csslint: {
            options: {
                csslintrc: '.csslintrc'
            },

            src: {
                src: 'src/*.css'
            }
        },

        concat: {
            build: {
                files: [
                    {'public/base.css': [
                        'bower_components/normalize-css/normalize.css',
                        'public/base.css'
                    ]},
                    {'public/grids.css': [
                        'tmp/grids-prefixed.css',
                        'public/grids.css'
                    ]},
                    // rollup
                    {'public/<%= pkg.name %>.css': [
                        'public/base.css',
                        'public/buttons.css',
                        'public/dropdowns.css',
                        'public/forms.css',
                        'public/grids.css',
                        'public/icons.css',
                        'public/layout.css',
                        'public/feedback.css',
                        'public/navigation.css',
                        'public/tables.css',
                        'public/typography.css'
                    ]}
                ]
            }
        },

        cssmin: {
            minify: {
                expand: true,
                cwd: 'public/',
                src: ['**.css', '!*-min.css'],
                dest: 'public/',
                ext: '-min.css'
            }
        },

        watch: {
            css: {
                files: 'src/**/*.css',
                tasks: ['rework', 'concat'],
                options: {
                    spawn: false
                }
            }
        },

        connect: {
            server: {
                options: {
                    port: 9001,
                    hostname: '*',
                    base: 'test'
                }
            }
        },
        rework: {
            files: {
                expand: true,
                cwd: 'src/',
                src: ['**/*.css'],
                dest: 'public/',
                ext: '.css'
            },
            options: {
                use: [
                    ['rework.keyframes'],
                    ['rework.prefix', 'border-radius'],
                    ['rework.prefix', 'box-shadow'],
                    ['rework.prefix', 'box-sizing'],
                    ['rework.prefix', 'animation'],
                    ['rework.prefix', 'transition'],
                    ['rework.prefixValue', 'linear-gradient']
                ],
                vendors: ['-o-', '-ms-', '-moz-', '-webkit-']
            }
        },

        css_selectors: {
            options: {
                mutations: [
                    {search: /^\.pure/g, replace: '.ues'}
                ]
            },
            pure_grids: {
                files: [
                    {dest: 'tmp/grids-prefixed.css', src: 'bower_components/pure/grids.css'}
                ]
            }
        },

        phantomcss: {
            desktop: {
                options: {
                    screenshots: 'test/visual/screenshots/desktop',
                    results: 'test_results/visual/desktop'
                },
                src: [
                    'test/visual/config/desktop.js'
                ]
            },
            smallscreen: {
                options: {
                    screenshots: 'test/visual/screenshots/smallscreen',
                    results: 'test_results/visual/smallscreen',
                    viewportSize: [320, 480]
                },
                src: [
                    'test/visual/config/smallscreen.js'
                ]
            },
        }
    });

    // configure csslint to only run on changed file
    grunt.event.on('watch', function(action, filepath) {
        grunt.config('csslint.src', filepath);
    });


    grunt.loadNpmTasks('grunt-contrib-clean');
    grunt.loadNpmTasks('grunt-contrib-compress');
    grunt.loadNpmTasks('grunt-contrib-concat');
    grunt.loadNpmTasks('grunt-contrib-copy');
    grunt.loadNpmTasks('grunt-contrib-csslint');
    grunt.loadNpmTasks('grunt-contrib-cssmin');
    grunt.loadNpmTasks('grunt-contrib-watch');
    grunt.loadNpmTasks('grunt-contrib-connect');
    grunt.loadNpmTasks('grunt-rework');
    grunt.loadNpmTasks('grunt-css-selectors');
    grunt.loadNpmTasks('grunt-phantomcss');

    grunt.registerTask('default',['run']);
    grunt.registerTask('test', ['build', 'connect', 'phantomcss']);
    grunt.registerTask('run', ['build', 'connect', 'watch']);
    grunt.registerTask('build', [
                       'clean:build',
                       'rework',
                       'csslint',
                       'css_selectors',
                       'concat',
                       'copy:icons',
                       'cssmin'
    ]);
    grunt.registerTask('release', [
        'build',
        'copy:release',
        'compress:release'
    ]);
}
